import os
#
#     Setting up a variable to specify the location of your final images
#     makes your script easier to read and more portable when you share it
#     with other users
#

homePath=expandpath('~')
dataPath=os.path.join(homePath,'Data')
scriptingPath=os.path.join(dataPath,'Scripting')

enhancementPath=os.path.join(scriptingPath,'Color-Enhancements')

areaPath=os.path.join(scriptingPath,'tornado-areas')
irPath=os.path.join(areaPath,'IR')
basePath=os.path.join(areaPath,'BASE')

#
#   imagePath is the directory to store final images
#   and/or animated gif files
#
imagePath=os.path.join(scriptingPath,'Images')

#
#   assign a temperature threshold used with mask() function
#
temperatureThreshold=250.0


#  
#     Create a dictionary for a basemap image  
#  
baseMapDataSet = makeLocalADDEEntry(dataset='TORNADO', imageType='Land Sea Mask', mask=basePath, format='McIDAS Area', save=True)  
baseMapParms = dict(  
    server='localhost',  
    localEntry=baseMapDataSet,  
    size='ALL'
)  
 
baseMapData=loadADDEImage(**baseMapParms)

irLocalDataSet = getLocalADDEEntry('TORNADO', 'GOES-13 IR')
ADDE_IR_loadRequest = dict(
    debug=True,
    server='localhost',
    localEntry=irLocalDataSet,
    size='ALL',
    mag=(1,1),
    position='ALL',
    unit='TEMP',
)

irData=loadADDEImage(**ADDE_IR_loadRequest)

#
#    Initialize a python list
#
myLoop=[]

#
#   Create a list of all available Images using listADDEImageTimes
#
dateTimeList=listADDEImageTimes(**ADDE_IR_loadRequest)

#
#   listADDEImages was successful, so now try loadADDEImage for each of the
#   directories returned.  There may be occasions when the loadADDEImage fails
#   but we want to continue
#
for dateTime in dateTimeList:

    imageTime = dateTime['time']
    print dateTime['time']

    ADDE_IR_loadRequest = dict(
        localEntry=irLocalDataSet,
        day=dateTime['day'],
        time=(imageTime,imageTime),
        band=4,
        unit='TEMP',
        size='ALL',
    )

    irData=loadADDEImage(**ADDE_IR_loadRequest)

#
#   Applying a mask is a two part process.
#   First we assign a value of 1 or missing value to a temporary data object
#   Second, multiply the first results to the temporary data object
#
    maskedData=mask(irData, 'lt', temperatureThreshold, 1)
    finalDataSet=mul(irData, maskedData)
    
    myLoop.append(finalDataSet)

#
#   Import enhancement tables
#
basemapTable=importColorTable(enhancementPath+'/Tornado-Basemap.xml', overwrite=True)
basemapTableName=basemapTable.getName()

IRTable=importColorTable(enhancementPath+'/Tornado-IR.xml',overwrite=True)
IRTableName=IRTable.getName()

#
#   Build a window and turn off the wireframe box
#
bwLines = 700
bwEles = 1000
panel = buildWindow(height=bwLines, width=bwEles)
panel[0].setWireframe(False)

#
#   Add individual layers to the existing window and set enhancement table and data ranges
#   Note that the layer order is important
#
baseMapLayer=panel[0].createLayer('Image Display', baseMapData)
baseMapLayer.setEnhancement(basemapTableName, range=(0,255))
baseMapLayer.setLayerLabel(' ',visible=False)

irLayer=panel[0].createLayer('Image Sequence Display',myLoop)
irLayer.setLayerLabel('%longname% Joplin Tornado Temperatures less than ' + str(temperatureThreshold) + ' %timestamp%')
irLayer.setEnhancement(IRTableName,range=(temperatureThreshold,200))

irLayer.setColorScale(visible=True, placement='Top', showUnit=True)

#
#   Set the center latitude, longitude and scale
#
panel[0].setProjection('US>Central U.S.')
panel[0].setCenter(35, -97, scale=1.5)

panel[0].annotate('Joplin, Missouri - <b>&gt</b>',lat=37.15, lon=-94.5,size=18, font='SansSerif.bold',alignment=('left','center'),color='White')
fileName=os.path.join(imagePath,'ir-base-loop.gif')
writeMovie(fileName)
