import os
#
#   The ** before the dictionary tells python to evaluate the contents of the
#   dictionary and include the keyword=parameter with the request to
#   loadADDEImage. Note, the dictionary must be the last parameter specified.
#
#
#     Setting up a variable to specify the location of your final images
#     makes your script easier to read and more portable when you share it
#     with other users
#

homePath=expandpath('~')
dataPath=os.path.join(homePath,'Data')
scriptingPath=os.path.join(dataPath,'Scripting')

enhancementPath=os.path.join(scriptingPath,'Color-Enhancements')

areaPath=os.path.join(scriptingPath,'tornado-areas')
irPath=os.path.join(areaPath,'IR')

#
#   imagePath is the directory to store final images
#   and/or animated gif files
#
imagePath=os.path.join(scriptingPath,'Images')

#
#   assign a temperature threshold used with mask() function
#
temperatureThreshold=250.0

#
#    Initialize a python list
#
myLoop=[]

#
#   Create a dictionary for requesting images
#
irLocalDataSet = getLocalADDEEntry(dataset='TORNADO',imageType='GOES-13 IR')
parms = dict(
    server='localhost',
    localEntry=irLocalDataSet,
    position='ALL'
)

#
#   Create a list of all available Images using listADDEImageTimes
#
dateTimeList=listADDEImageTimes(**parms)

#
#   listADDEImages was successful, so now try loadADDEImage for each of the
#   directories returned.  There may be occasions when the loadADDEImage fails
#   but we want to continue
#
for dateTime in dateTimeList:

    imageTime = dateTime['time']
    print dateTime['time']

    ADDE_IR_loadRequest = dict(
        localEntry=irLocalDataSet,
        day=dateTime['day'],
        time=(imageTime,imageTime),
        band=4,
        unit='TEMP',
        size='ALL',
    )

    irData=loadADDEImage(**ADDE_IR_loadRequest)
    

#
#   Applying a mask is a two part process.
#   First we assign a value of 1 or missing value to a temporaary data object
#   Second, multiply the first results to the temporary data object
#
    maskedData=mask(irData, 'lt', temperatureThreshold, 1)
    finalDataSet=mul(irData, maskedData)

    myLoop.append(finalDataSet)

#
#   Import enhancement table
#
IRTable=importColorTable(enhancementPath+'/Tornado-IR.xml',overwrite=True)
IRTableName=IRTable.getName()

#
#   Build a window and turn off the wireframe box
#
bwLines = irData['lines'] / 2
bwEles = irData['elements'] / 2
panel = buildWindow(height=bwLines, width=bwEles)
panel[0].setWireframe(False)

#
#   Add layers to the existing window set enhancement table and data ranges
#
irLayer=panel[0].createLayer('Image Sequence Display', myLoop)
irLayer.setLayerLabel('GOES-13 Temperatures less than ' + str(temperatureThreshold) + ' %timestamp%')
irLayer.setEnhancement(IRTableName, range=(temperatureThreshold,200))


#
#   Set the center latitude, longitude and scale
#
panel[0].setProjection('US>States>N-Z>Oklahoma')
panel[0].setCenter(33,-97,scale=.5)

fileName=os.path.join(imagePath,'ir-loop.gif')
writeMovie(fileName)